@@ -4,6 +4,7 @@
 # License: BSD 3 clause
 
 import numpy as np
+from sysidentpy.utils._check_arrays import check_random_state
 
 
 class BPSOGSA:
@@ -142,7 +143,7 @@ class BPSOGSA:
 
         return self
 
-    def generate_random_population(self):
+    def generate_random_population(self, random_state=None):
         """Generate the initial population of agents randomly
 
         Returns
@@ -150,7 +151,8 @@ class BPSOGSA:
         population : ndarray of zeros and ones
             The initial population of agents.
         """
-        population = np.random.choice(
+        rng = check_random_state(random_state)
+        population = rng.choice(
             [0, 1], size=(self.dimension, self.n_agents), p=[self.p_zeros, self.p_ones]
         )
         return population
